[llvm] 25affb0 - [CMake][AIX] Limit tools in external project build

David Tenty via llvm-commits llvm-commits at lists.llvm.org
Mon Sep 28 14:00:05 PDT 2020


Author: David Tenty
Date: 2020-09-28T16:59:25-04:00
New Revision: 25affb04aab7ad55bd7c0dc95e8c2d3973ab8f6d

URL: https://github.com/llvm/llvm-project/commit/25affb04aab7ad55bd7c0dc95e8c2d3973ab8f6d
DIFF: https://github.com/llvm/llvm-project/commit/25affb04aab7ad55bd7c0dc95e8c2d3973ab8f6d.diff

LOG: [CMake][AIX] Limit tools in external project build

This is a follow on to D85329 which disabled some llvm tools in the
runtimes build due to XCOFF64 limitations. This change disables them
in other external project builds as well, when no list of tools is
specified in the arguments.

Reviewed By: hubert.reinterpretcast, stevewan

Differential Revision: https://reviews.llvm.org/D88310

Added: 
    

Modified: 
    llvm/cmake/modules/LLVMExternalProjectUtils.cmake

Removed: 
    


################################################################################
diff  --git a/llvm/cmake/modules/LLVMExternalProjectUtils.cmake b/llvm/cmake/modules/LLVMExternalProjectUtils.cmake
index ad6475729fbd..1b4a1f339e2b 100644
--- a/llvm/cmake/modules/LLVMExternalProjectUtils.cmake
+++ b/llvm/cmake/modules/LLVMExternalProjectUtils.cmake
@@ -59,14 +59,18 @@ function(llvm_ExternalProject_Add name source_dir)
   endif()
 
   if(NOT ARG_TOOLCHAIN_TOOLS)
-    set(ARG_TOOLCHAIN_TOOLS clang lld llvm-ar llvm-ranlib llvm-nm llvm-objdump)
-    if(_cmake_system_name STREQUAL Darwin)
-      list(APPEND ARG_TOOLCHAIN_TOOLS llvm-libtool-darwin llvm-lipo)
-    elseif(_cmake_system_name STREQUAL Windows)
-      list(APPEND ARG_TOOLCHAIN_TOOLS llvm-lib)
-    else()
-      # TODO: These tools don't fully support Mach-O format yet.
-      list(APPEND ARG_TOOLCHAIN_TOOLS llvm-objcopy llvm-strip)
+    set(ARG_TOOLCHAIN_TOOLS clang)
+    # AIX 64-bit XCOFF and big AR format is not yet supported in some of these tools.
+    if(NOT _cmake_system_name STREQUAL AIX)
+      list(APPEND ARG_TOOLCHAIN_TOOLS lld llvm-ar llvm-ranlib llvm-nm llvm-objdump)
+      if(_cmake_system_name STREQUAL Darwin)
+        list(APPEND ARG_TOOLCHAIN_TOOLS llvm-libtool-darwin llvm-lipo)
+      elseif(_cmake_system_name STREQUAL Windows)
+        list(APPEND ARG_TOOLCHAIN_TOOLS llvm-lib)
+      else()
+        # TODO: These tools don't fully support Mach-O format yet.
+        list(APPEND ARG_TOOLCHAIN_TOOLS llvm-objcopy llvm-strip)
+      endif()
     endif()
   endif()
   foreach(tool ${ARG_TOOLCHAIN_TOOLS})


        


More information about the llvm-commits mailing list